@@ -46,32 +46,34 @@ OC.L10N.register(
     "Next week" : "Minggu setelah",
     "Next year" : "Tahun depan",
     "Next month" : "Bulan setelah",
-    "Event" : "Acara",
     "Create new event" : "Buat acara baru",
+    "Event" : "Acara",
     "Today" : "Hari Ini",
     "Day" : "Hari",
     "Week" : "Minggu",
     "Month" : "Bulan",
     "Year" : "Tahun",
     "List" : "daftar",
+    "Appointment link was copied to clipboard" : "Tautan janji temu disalin ke papan klip",
+    "Appointment link could not be copied to clipboard" : "Tautan janji temu tidak dapat disalin ke papan klip",
     "Preview" : "Pratinjau",
     "Copy link" : "Salin tautan",
     "Edit" : "Sunting",
     "Delete" : "Hapus",
-    "Appointment link was copied to clipboard" : "Tautan janji temu disalin ke papan klip",
-    "Appointment link could not be copied to clipboard" : "Tautan janji temu tidak dapat disalin ke papan klip",
     "Create new" : "Buat",
-    "Untitled calendar" : "Kalender tanpa judul",
-    "Shared with you by" : "Dibagikan dengan Anda oleh",
-    "Edit and share calendar" : "Edit dan bagikan kalender",
-    "Edit calendar" : "Edit kalender",
     "Disable calendar \"{calendar}\"" : "Nonaktifkan kalender \"{calendar}\"",
     "Disable untitled calendar" : "Nonaktifkan kalender tanpa judul",
     "Enable calendar \"{calendar}\"" : "Aktifkan kalender \"{calendar}\"",
     "Enable untitled calendar" : "Aktifkan kalender tanpa judul",
     "An error occurred, unable to change visibility of the calendar." : "Terjadi galat, tidak dapat mengubah visibilitas kalender.",
+    "Untitled calendar" : "Kalender tanpa judul",
+    "Shared with you by" : "Dibagikan dengan Anda oleh",
+    "Edit and share calendar" : "Edit dan bagikan kalender",
+    "Edit calendar" : "Edit kalender",
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Batal berbagi kalender dalam {countdown} detik"],
     "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Menghapus kalender dalam {countdown} detik"],
+    "An error occurred, unable to create the calendar." : "Terjadi galat, tidak dapat membuat kalender.",
+    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Silakan isi tautan valid (dimulai dengan http://, https://, webcal://, or webcals://)",
     "Calendars" : "Kalender",
     "Add new" : "Tambahkan baru",
     "New calendar" : "Kalender baru",
@@ -82,15 +84,19 @@ OC.L10N.register(
     "Creating subscription …" : "Membuat langganan …",
     "Add public holiday calendar" : "Tambahkan kalender hari libur nasional",
     "Add custom public calendar" : "Tambahkan kalender publik khusus",
-    "An error occurred, unable to create the calendar." : "Terjadi galat, tidak dapat membuat kalender.",
-    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Silakan isi tautan valid (dimulai dengan http://, https://, webcal://, or webcals://)",
+    "Calendar link copied to clipboard." : "Tautan kalender disalin ke papan klip.",
+    "Calendar link could not be copied to clipboard." : "Tautan kalender tidak dapat disalin ke papan klip.",
     "Copy subscription link" : "Salin tautan berlangganan",
     "Copying link …" : "Menyalin tautan …",
     "Copied link" : "Tautan tersalin",
     "Could not copy link" : "Tidak dapat menyalin tautan",
     "Export" : "Ekspor",
-    "Calendar link copied to clipboard." : "Tautan kalender disalin ke papan klip.",
-    "Calendar link could not be copied to clipboard." : "Tautan kalender tidak dapat disalin ke papan klip.",
+    "Untitled item" : "Item tanpa judul",
+    "Unknown calendar" : "Kalender tidak diketahui",
+    "Could not load deleted calendars and objects" : "Tidak dapat memuat kalender dan objek yang dihapus",
+    "Could not restore calendar or event" : "Tidak dapat memulihkan kalender atau acara",
+    "Do you really want to empty the trash bin?" : "Apakah Anda benar-benar ingin mengosongkan keranjang sampah?",
+    "Empty trash bin" : "Kosongkan tempat sampah",
     "Trash bin" : "Keranjang sampah",
     "Loading deleted items." : "Memuat item yang dihapus.",
     "You do not have any deleted items." : "Anda tidak memiliki item yang dihapus.",
@@ -98,16 +104,15 @@ OC.L10N.register(
     "Deleted" : "Dihapus",
     "Restore" : "Pulihkan",
     "Delete permanently" : "Hapus secara permanen",
-    "Empty trash bin" : "Kosongkan tempat sampah",
-    "Untitled item" : "Item tanpa judul",
-    "Unknown calendar" : "Kalender tidak diketahui",
-    "Could not load deleted calendars and objects" : "Tidak dapat memuat kalender dan objek yang dihapus",
-    "Could not restore calendar or event" : "Tidak dapat memulihkan kalender atau acara",
-    "Do you really want to empty the trash bin?" : "Apakah Anda benar-benar ingin mengosongkan keranjang sampah?",
     "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Item dalam keranjang sampah dihapus setelah {numDays} hari"],
+    "Could not update calendar order." : "Tidak dapat membarui urutan kalender.",
     "Deck" : "Longgok",
     "Hidden" : "Sembunyi",
-    "Could not update calendar order." : "Tidak dapat membarui urutan kalender.",
+    "An error occurred, unable to publish calendar." : "Terjadi galat, tidak dapat menerbitkan kalender.",
+    "An error occurred, unable to send email." : "Terjadi galat, tidak dapat mengirim surel.",
+    "Embed code copied to clipboard." : "Kode tersemat disalin ke papan klip",
+    "Embed code could not be copied to clipboard." : "Kode tersemat tidak dapat disalin ke papan klip.",
+    "Unpublishing calendar failed" : "Gagal membatalkan penerbitan kalender",
     "Share link" : "Bagikan tautan",
     "Copy public link" : "Salin tautan publik",
     "Send link to calendar via email" : "Kirim tautan kalender via surel",
@@ -118,15 +123,10 @@ OC.L10N.register(
     "Could not copy code" : "Tidak dapat menyalin kode",
     "Delete share link" : "Hapus tautan berbagi",
     "Deleting share link …" : "Menghapus tautan berbagi …",
-    "An error occurred, unable to publish calendar." : "Terjadi galat, tidak dapat menerbitkan kalender.",
-    "An error occurred, unable to send email." : "Terjadi galat, tidak dapat mengirim surel.",
-    "Embed code copied to clipboard." : "Kode tersemat disalin ke papan klip",
-    "Embed code could not be copied to clipboard." : "Kode tersemat tidak dapat disalin ke papan klip.",
-    "Unpublishing calendar failed" : "Gagal membatalkan penerbitan kalender",
-    "can edit" : "dapat edit",
-    "Unshare with {displayName}" : "Batal berbagi dengan {displayName}",
     "An error occurred while unsharing the calendar." : "Terjadi kesalahan saat membatalkan pembagian kalender. ",
     "An error occurred, unable to change the permission of the share." : "Terjadi galat, tidak dapat mengubah hak akses berbagi.",
+    "can edit" : "dapat edit",
+    "Unshare with {displayName}" : "Batal berbagi dengan {displayName}",
     "Share with users or groups" : "Berbagi dengan pengguna atau grup",
     "No users or groups" : "Tidak ada pengguna atau grup",
     "Save" : "Simpan",
@@ -142,8 +142,6 @@ OC.L10N.register(
     "Automatic" : "Otomatis",
     "Automatic ({detected})" : "Otomatis ({detected})",
     "New setting was not saved successfully." : "Setelan baru tidak berhasil tersimpan.",
-    "Shortcut overview" : "Ikhtisar pintasan",
-    "or" : "atau",
     "Navigation" : "Navigasi",
     "Previous period" : "Periode sebelum",
     "Next period" : "Periode sesudah",
@@ -155,6 +153,10 @@ OC.L10N.register(
     "Actions" : "Tindakan",
     "Create event" : "Buat acara",
     "Show shortcuts" : "Tampilkan pintasan",
+    "Shortcut overview" : "Ikhtisar pintasan",
+    "or" : "atau",
+    "CalDAV link copied to clipboard." : "Tautan CalDAV disalin ke papan klip",
+    "CalDAV link could not be copied to clipboard." : "Tautan CalDAV tidak dapat disalin ke papan klip",
     "Enable birthday calendar" : "Aktifkan kalender ulang tahun",
     "Show tasks in calendar" : "Tampilkan tugas dalam kalender",
     "Enable simplified editor" : "Aktifkan editor serderhana",
@@ -163,9 +165,8 @@ OC.L10N.register(
     "Copy primary CalDAV address" : "Salin alamat utama CalDAV",
     "Copy iOS/macOS CalDAV address" : "Salin alamat CalDAV iOS/macOS",
     "Show keyboard shortcuts" : "Tampilkan pintasan papan kunci",
-    "CalDAV link copied to clipboard." : "Tautan CalDAV disalin ke papan klip",
-    "CalDAV link could not be copied to clipboard." : "Tautan CalDAV tidak dapat disalin ke papan klip",
     "To configure appointments, add your email address in personal settings." : "Untuk mengonfigurasi janji temu, tambahkan alamat surel Anda di pengaturan pribadi.",
+    "Update" : "Perbarui",
     "Location" : "Lokasi",
     "Description" : "Deskrisi",
     "to" : "untuk",
@@ -177,10 +178,11 @@ OC.L10N.register(
     "Friday" : "Jumat",
     "Saturday" : "Sabtu",
     "Sunday" : "Minggu",
-    "Update" : "Perbarui",
     "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Kami telah mengirim surel dengan detailnya. Mohon konfirmasikan janji temu Anda menggunakan tautan dalam surel tersebut. Anda dapat menutup halaman ini sekarang.",
     "Your email address" : "Alamat surel Anda",
     "Could not book the appointment. Please try again later or contact the organizer." : "Tidak dapat memesan janji temu. Mohon coba lagi nanti atau hubungi penyelenggara.",
+    "on" : "pada",
+    "at" : "di",
     "Notification" : "Notifikasi",
     "Email" : "Surel",
     "Audio notification" : "Notifikasi audio",
@@ -190,69 +192,63 @@ OC.L10N.register(
     "Edit time" : "Edit waktu",
     "Save time" : "Simpan waktu",
     "Remove reminder" : "Buang pengingat",
-    "on" : "pada",
-    "at" : "di",
     "+ Add reminder" : "+ Tambah pengingat",
-    "_second_::_seconds_" : ["detik"],
-    "_minute_::_minutes_" : ["menit"],
-    "_hour_::_hours_" : ["jam"],
-    "_day_::_days_" : ["hari"],
-    "_week_::_weeks_" : ["minggu"],
-    "Delete file" : "Hapus berkas",
+    "seconds" : "detik",
+    "minutes" : "menit",
+    "hours" : "jam",
+    "days" : "hari",
+    "weeks" : "minggu",
     "Choose a file to add as attachment" : "Pilih berkas untuk ditambahkan sebagai lampiran",
+    "Delete file" : "Hapus berkas",
     "Not available" : "Tidak tersedia",
-    "Availability of attendees, resources and rooms" : "Ketersediaan peserta, sumber daya, dan ruangan",
-    "Done" : "Selesai",
     "Free" : "Luang",
     "Busy (tentative)" : "Sibuk (tentatif)",
     "Busy" : "Sibuk",
     "Out of office" : "Keluar kantor",
     "Unknown" : "Tidak diketahui",
+    "Availability of attendees, resources and rooms" : "Ketersediaan peserta, sumber daya, dan ruangan",
+    "Done" : "Selesai",
     "Room name" : "Nama ruang",
-    "Accept" : "Terima",
-    "Decline" : "Tolak",
-    "Tentative" : "Tentatif",
     "The invitation has been accepted successfully." : "Undangan berhasil diterima.",
     "Failed to accept the invitation." : "Gagal menerima undangan.",
     "The invitation has been declined successfully." : "Undangan berhasil ditolak.",
     "Failed to decline the invitation." : "Gagal menolak undangan.",
     "Your participation has been marked as tentative." : "Partisipasi Anda telah ditandai sebagai belum pasti.",
     "Failed to set the participation status to tentative." : "Gagal menyetel status partisipasi menjadi belum pasti.",
-    "Attendees" : "Peserta",
-    "Create Talk room for this event" : "Buat ruangan Talk untuk acara ini",
+    "Accept" : "Terima",
+    "Decline" : "Tolak",
+    "Tentative" : "Tentatif",
     "No attendees yet" : "Belum ada peserta",
     "Successfully appended link to talk room to description." : "Berhasil menambahkan tautan ruang Talk pada deskripsi.",
     "Error creating Talk room" : "Galat membuat ruangan Talk",
+    "Attendees" : "Peserta",
+    "Remove group" : "Hapus grup",
+    "Remove attendee" : "Hapus peserta",
     "Required participant" : "Partisipan wajib",
     "Optional participant" : "Partisipan opsional",
     "Non-participant" : "Bukan partisipan",
-    "Remove group" : "Hapus grup",
-    "Remove attendee" : "Hapus peserta",
     "No match found" : "Tidak ditemukan kecocokan",
     "Note that members of circles get invited but are not synced yet." : "Perhatikan bahwa anggota kelompok diundang tapi belum tersinkronisasi.",
     "(organizer)" : "(penyelenggara)",
     "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Untuk mengirim undangan dan mengurus respons, [linkopen]tambahkan alamat surel Anda di pengaturan pribadi[linkclose].",
     "Remove color" : "Hapus warna",
     "Event title" : "Judul acara",
-    "All day" : "Sepanjang hari",
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Tidak dapat mengubah pengaturan sehari penuh untuk acara yang merupakan bagian dari set pengulangan.",
+    "All day" : "Sepanjang hari",
     "Repeat" : "Ulang",
-    "End repeat" : "Akhiri perulangan",
-    "Select to end repeat" : "Pilih untuk mengakhiri perulangan",
     "never" : "tidak pernah",
     "on date" : "pada tanggal",
     "after" : "setelah",
+    "End repeat" : "Akhiri perulangan",
+    "Select to end repeat" : "Pilih untuk mengakhiri perulangan",
     "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Acara ini merupakan pengecualian pengulangan dari set pengulangan. Anda tidak dapat menambahkan aturan pengulangan pada acara ini.",
     "first" : "pertama",
-    "third" : "ke-3",
-    "fourth" : "ke-4",
-    "fifth" : "ke-5",
-    "second to last" : "kedua terakhir",
-    "last" : "terakhir",
     "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Perubahan pada aturan pengulangan hanya akan diterapkan untuk acara ini dan semua acara selanjutnya.",
     "Repeat every" : "Ulang setiap",
     "By day of the month" : "Berdasarkan hari pada bulan",
     "On the" : "Pada",
+    "_day_::_days_" : ["hari"],
+    "_week_::_weeks_" : ["minggu"],
     "_month_::_months_" : ["bulang"],
     "_year_::_years_" : ["tahun"],
     "weekday" : "akhir pekan",
@@ -260,16 +256,16 @@ OC.L10N.register(
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Penentuan perulangan acara ini tidak sepenuhnya didukung oleh Nextcloud. Jika Anda mengedit opsi pengulangan, pengulangan tertentu mungkin hilang.",
     "Public calendar does not exist" : "Kalender publik tidak eksis",
     "Maybe the share was deleted or has expired?" : "Mungkin yang dibagikan terhapus atau kadaluwarsa?",
-    "Pick a time" : "Pilih waktu",
-    "Pick a date" : "Pilih tanggal",
     "Please enter a valid date" : "Silakan isi tanggal valid",
     "Please enter a valid date and time" : "Silakan isi tanggal dan waktu valid",
+    "Pick a time" : "Pilih waktu",
+    "Pick a date" : "Pilih tanggal",
+    "An error occurred, unable to read public calendars." : "Terjadi kesalahan, tidak dapat membaca kalender umum.",
+    "An error occurred, unable to subscribe to calendar." : "Terjadi kesalahan, tidak dapat berlangganan kalender.",
     "Speak to the server administrator to resolve this issue." : "Hubungi administrator server untuk menyelesaikan masalah ini.",
     "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Kalender hari libur nasional disediakan oleh Thunderbird. Data kalender akan diunduh dari {website}",
     "These public calendars are suggested by the sever administrator. Calendar data will be downloaded from the respective website." : "Kalender-kalender umum ini disarankan oleh administrator server. data Kalender akan diunduh dari situs web masing-masing.",
     "Subscribe" : "Berlangganan",
-    "An error occurred, unable to read public calendars." : "Terjadi kesalahan, tidak dapat membaca kalender umum.",
-    "An error occurred, unable to subscribe to calendar." : "Terjadi kesalahan, tidak dapat berlangganan kalender.",
     "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Terima kasih. Pemesanan Anda dari {startDate} hingga  {endDate} telah dikonfirmasi.",
     "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Slot untuk janji temu Anda dari {startDate} hingga {endDate} tidak lagi tersedia.",
     "Personal" : "Pribadi",
@@ -277,8 +273,8 @@ OC.L10N.register(
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Zona waktu Anda yang terkonfigurasi ({timezoneId}) tidak ditemukan. Kembali ke UTC.\nHarap ubah zona waktu Anda di pengaturan dan laporkan masalah ini.",
     "Details" : "Detail",
     "Resources" : "Sumber daya",
-    "Close" : "Tutup",
     "Untitled event" : "Acara tanpa judul",
+    "Close" : "Tutup",
     "Subscribe to {name}" : "Berlangganan ke {name}",
     "Anniversary" : "Hari jadi",
     "Appointment" : "Janji",
@@ -319,13 +315,18 @@ OC.L10N.register(
     "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["pada hari {dayOfMonthList}"],
     "until {untilDate}" : "sampai {untilDate}",
     "_%n time_::_%n times_" : ["%n kali"],
+    "second" : "detik",
+    "third" : "ke-3",
+    "fourth" : "ke-4",
+    "fifth" : "ke-5",
+    "second to last" : "kedua terakhir",
+    "last" : "terakhir",
     "Untitled task" : "Tugas tanpa judul",
     "Please ask your administrator to enable the Tasks App." : "Silakan tanya administrator Anda untuk mengaktifkan aplikasi Tugas.",
     "_+%n more_::_+%n more_" : ["+%n lagi"],
     "Other" : "Lainnya",
     "The visibility of this event in shared calendars." : "Visibilitas acara ini di kalender yang dibagikan.",
     "Add a location" : "Tambah lokasi",
-    "Add a description" : "Tambah deskripsi",
     "Status" : "Status",
     "Confirmed" : "Terkonfirmasi",
     "Confirmation about the overall status of the event." : "Konfirmasi tentang status keseluruhan acara.",
@@ -337,9 +338,7 @@ OC.L10N.register(
     "Add this as a new category" : "Tambah sebagai kategori baru",
     "Custom color" : "Warna khusus",
     "Special color of this event. Overrides the calendar-color." : "Warna spesial dari acara ini. Mengganti warna kalender.",
-    "Chat room for event" : "Ruang obrolan untuk acara",
     "An error occurred, unable to delete the calendar." : "Terjadi galat, tidak dapat menghapus kalender.",
-    "This is an event reminder." : "Ini adalah pengingat acara.",
-    "[Today]" : "[Hari ini]"
+    "This is an event reminder." : "Ini adalah pengingat acara."
 },
 "nplurals=1; plural=0;");
