@@ -10,22 +10,27 @@ OC.L10N.register(
     "Cheers!" : "ไชโย!",
     "Calendar" : "ปฏิทิน",
     "Confirm" : "ยืนยัน",
-    "New event" : "เหตุการณ์ใหม่",
+    "Previous year" : "ปีที่แล้ว",
+    "Next year" : "ปีหน้า",
     "Today" : "วันนี้",
     "Day" : "วัน",
     "Week" : "สัปดาห์",
     "Month" : "เดือน",
+    "Year" : "ปี",
     "Preview" : "ตัวอย่าง",
     "Copy link" : "คัดลอกลิงก์",
     "Edit" : "แก้ไข",
     "Delete" : "ลบ",
+    "Create new" : "สร้างใหม่",
+    "Calendars" : "ปฏิทิน",
     "New calendar" : "สร้างปฏิทินใหม่",
     "Export" : "ส่งออก",
+    "Empty trash bin" : "ล้างข้อมูลในถังขยะ",
     "Name" : "ชื่อ",
     "Deleted" : "ลบแล้ว",
     "Restore" : "คืนค่า",
     "Delete permanently" : "ลบแบบถาวร",
-    "Empty trash bin" : "ล้างข้อมูลในถังขยะ",
+    "Hidden" : "ซ่อนอยู่",
     "Share link" : "แชร์ลิงก์",
     "can edit" : "สามารถแก้ไข",
     "Share with users or groups" : "แชร์กับผู้ใช้หรือกลุ่ม",
@@ -33,8 +38,11 @@ OC.L10N.register(
     "Filename" : "ชื่อไฟล์",
     "Cancel" : "ยกเลิก",
     "Automatic" : "อัตโนมัติ",
+    "Year view" : "มุมมองรายปี",
     "List view" : "มุมมองแบบรายการ",
     "Actions" : "การกระทำ",
+    "_{duration} year_::_{duration} years_" : ["{duration}ปี"],
+    "Update" : "อัปเดต",
     "Location" : "ตำแหน่ง",
     "Description" : "คำอธิบาย",
     "to" : "ถึง",
@@ -46,42 +54,45 @@ OC.L10N.register(
     "Friday" : "วันศุกร์",
     "Saturday" : "วันเสาร์",
     "Sunday" : "วันอาทิตย์",
-    "Update" : "อัปเดต",
     "Your email address" : "ที่อยู่อีเมลของคุณ",
+    "Notification" : "การแจ้งเตือน",
     "Email" : "อีเมล",
-    "Delete file" : "ลบไฟล์",
+    "seconds" : "วินาที",
+    "minutes" : "นาที",
+    "hours" : "ชั่วโมง",
+    "days" : "วัน",
+    "weeks" : "สัปดาห์",
     "Choose a file to add as attachment" : "เลือกไฟล์ที่ต้องการแนบ",
+    "Delete file" : "ลบไฟล์",
     "Unknown" : "ไม่ทราบ",
     "Accept" : "ยอมรับ",
     "Decline" : "ปฏิเสธ",
     "Tentative" : "ชั่วคราว",
-    "Send email" : "ส่งอีเมล",
+    "Attendees" : "ผู้เข้าร่วมกิจกรรม",
+    "Remove group" : "ลบกลุ่ม",
     "Repeat" : "ทำซ้ำ",
     "never" : "ไม่ต้องเลย",
     "after" : "หลังจาก",
-    "More" : "เพิ่มเติม",
     "Pick a date" : "เลือกวันที่",
     "Global" : "ทั่วไป",
     "Subscribe" : "สมัครรับข้อมูล",
     "Personal" : "ส่วนตัว",
     "Details" : "รายละเอียด",
-    "Attendees" : "ผู้เข้าร่วมกิจกรรม",
+    "Resources" : "ทรัพยากร",
     "Close" : "ปิด",
     "Anniversary" : "วันครบรอบ",
     "Week {number} of {year}" : "สัปดาห์ที่ {number} ของปี {year}",
     "Daily" : "รายวัน",
     "Weekly" : "รายสัปดาห์",
+    "Monthly" : "ทุก ๆ เดือน",
+    "Yearly" : "ทุก ๆ ปี",
+    "second" : "วินาที",
     "Other" : "อื่น ๆ",
     "When shared show full event" : "เมื่อแชร์จะแสดงกิจกรรมเต็ม",
     "When shared show only busy" : "เมื่อแชร์จะแสดงเฉพาะไม่ว่าง",
     "When shared hide this event" : "เมื่อแชร์จะซ่อนกิจกรรมนี้",
     "Status" : "สถานะ",
     "Confirmed" : "ยืนยันแล้ว",
-    "Categories" : "หมวดหมู่",
-    "Commuting" : "กำลังเดินทาง",
-    "Presentation" : "งานนำเสนอ",
-    "Office" : "สำนักงาน",
-    "Mail" : "จดหมาย",
-    "Birthday" : "วันเกิด"
+    "Categories" : "หมวดหมู่"
 },
 "nplurals=1; plural=0;");
